==> modemmanager-qt-5.20.0.zip: modemmanager-qt-5.20.0/src/modemcdma_p.h <==
/*
    Copyright 2008 Will Stephenson <wstephenson@kde.org>
    Copyright 2010 Lamarque Souza <lamarque@kde.org>
    Copyright 2013-2015 Jan Grulich <jgrulich@redhat.com>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef MODEMMANAGERQT_MODEMCDMA_P_H
#define MODEMMANAGERQT_MODEMCDMA_P_H

#include "dbus/modemcdmainterface.h"
#include "interface_p.h"
#include "modemcdma.h"

namespace ModemManager
{

class ModemCdmaPrivate: public InterfacePrivate
{
public:
    explicit ModemCdmaPrivate(const QString &path, ModemCdma *q);
    OrgFreedesktopModemManager1ModemModemCdmaInterface modemCdmaIface;

    MMModemCdmaActivationState activationState;
    QString meid;
    QString esn;
    uint sid;
    uint nid;
    MMModemCdmaRegistrationState cdma1xRegistrationState;
    MMModemCdmaRegistrationState evdoRegistrationState;

    Q_DECLARE_PUBLIC(ModemCdma)
    ModemCdma *q_ptr;
private Q_SLOTS:
    void onActivationStateChanged(uint activation_state, uint activation_error, const QVariantMap &status_changes);
    virtual void onPropertiesChanged(const QString &interface, const QVariantMap &properties, const QStringList &invalidatedProps) Q_DECL_OVERRIDE;
};

} // namespace ModemManager

#endif

==> modemmanager-qt-5.54.0.zip: modemmanager-qt-5.54.0/src/modemcdma_p.h <==
/*
    Copyright 2008 Will Stephenson <wstephenson@kde.org>
    Copyright 2010 Lamarque Souza <lamarque@kde.org>
    Copyright 2013-2015 Jan Grulich <jgrulich@redhat.com>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef MODEMMANAGERQT_MODEMCDMA_P_H
#define MODEMMANAGERQT_MODEMCDMA_P_H

#include "dbus/modemcdmainterface.h"
#include "interface_p.h"
#include "modemcdma.h"

namespace ModemManager
{

class ModemCdmaPrivate: public InterfacePrivate
{
public:
    explicit ModemCdmaPrivate(const QString &path, ModemCdma *q);
    OrgFreedesktopModemManager1ModemModemCdmaInterface modemCdmaIface;

    MMModemCdmaActivationState activationState;
    QString meid;
    QString esn;
    uint sid;
    uint nid;
    MMModemCdmaRegistrationState cdma1xRegistrationState;
    MMModemCdmaRegistrationState evdoRegistrationState;

    Q_DECLARE_PUBLIC(ModemCdma)
    ModemCdma *q_ptr;
private Q_SLOTS:
    void onActivationStateChanged(uint activation_state, uint activation_error, const QVariantMap &status_changes);
    void onPropertiesChanged(const QString &interface, const QVariantMap &properties, const QStringList &invalidatedProps) override;
};

} // namespace ModemManager

#endif
